diff --git a/light_client_app/android/gradle/wrapper/gradle-wrapper.jar b/light_client_app/android/gradle/wrapper/gradle-wrapper.jar
index e708b1c0..2c352119 100644
Binary files a/light_client_app/android/gradle/wrapper/gradle-wrapper.jar and b/light_client_app/android/gradle/wrapper/gradle-wrapper.jar differ
diff --git a/light_client_app/android/gradle/wrapper/gradle-wrapper.properties b/light_client_app/android/gradle/wrapper/gradle-wrapper.properties
index 368d7f2d..09523c0e 100644
--- a/light_client_app/android/gradle/wrapper/gradle-wrapper.properties
+++ b/light_client_app/android/gradle/wrapper/gradle-wrapper.properties
@@ -1,6 +1,7 @@
-#Tue Jul 23 21:54:24 CDT 2024
distributionBase=GRADLE_USER_HOME
distributionPath=wrapper/dists
-distributionUrl=https\://services.gradle.org/distributions/gradle-8.0-bin.zip
+distributionUrl=https\://services.gradle.org/distributions/gradle-8.9-bin.zip
+networkTimeout=10000
+validateDistributionUrl=true
zipStoreBase=GRADLE_USER_HOME
zipStorePath=wrapper/dists
diff --git a/light_client_app/android/gradlew b/light_client_app/android/gradlew
index 4f906e0c..f5feea6d 100755
--- a/light_client_app/android/gradlew
+++ b/light_client_app/android/gradlew
@@ -1,7 +1,7 @@
-#!/usr/bin/env sh
+#!/bin/sh
#
-# Copyright 2015 the original author or authors.
+# Copyright © 2015-2021 the original authors.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
@@ -15,69 +15,104 @@
# See the License for the specific language governing permissions and
# limitations under the License.
#
+# SPDX-License-Identifier: Apache-2.0
+#
##############################################################################
-##
-## Gradle start up script for UN*X
-##
+#
+# Gradle start up script for POSIX generated by Gradle.
+#
+# Important for running:
+#
+# (1) You need a POSIX-compliant shell to run this script. If your /bin/sh is
+# noncompliant, but you have some other compliant shell such as ksh or
+# bash, then to run this script, type that shell name before the whole
+# command line, like:
+#
+# ksh Gradle
+#
+# Busybox and similar reduced shells will NOT work, because this script
+# requires all of these POSIX shell features:
+# * functions;
+# * expansions «$var», «${var}», «${var:-default}», «${var+SET}»,
+# «${var#prefix}», «${var%suffix}», and «$( cmd )»;
+# * compound commands having a testable exit status, especially «case»;
+# * various built-in commands including «command», «set», and «ulimit».
+#
+# Important for patching:
+#
+# (2) This script targets any POSIX shell, so it avoids extensions provided
+# by Bash, Ksh, etc; in particular arrays are avoided.
+#
+# The "traditional" practice of packing multiple parameters into a
+# space-separated string is a well documented source of bugs and security
+# problems, so this is (mostly) avoided, by progressively accumulating
+# options in "$@", and eventually passing that to Java.
+#
+# Where the inherited environment variables (DEFAULT_JVM_OPTS, JAVA_OPTS,
+# and GRADLE_OPTS) rely on word-splitting, this is performed explicitly;
+# see the in-line comments for details.
+#
+# There are tweaks for specific operating systems such as AIX, CygWin,
+# Darwin, MinGW, and NonStop.
+#
+# (3) This script is generated from the Groovy template
+# https://github.com/gradle/gradle/blob/HEAD/platforms/jvm/plugins-application/src/main/resources/org/gradle/api/internal/plugins/unixStartScript.txt
+# within the Gradle project.
+#
+# You can find Gradle at https://github.com/gradle/gradle/.
+#
##############################################################################
# Attempt to set APP_HOME
+
# Resolve links: $0 may be a link
-PRG="$0"
-# Need this for relative symlinks.
-while [ -h "$PRG" ] ; do
- ls=`ls -ld "$PRG"`
- link=`expr "$ls" : '.*-> \(.*\)$'`
- if expr "$link" : '/.*' > /dev/null; then
- PRG="$link"
- else
- PRG=`dirname "$PRG"`"/$link"
- fi
+app_path=$0
+
+# Need this for daisy-chained symlinks.
+while
+ APP_HOME=${app_path%"${app_path##*/}"} # leaves a trailing /; empty if no leading path
+ [ -h "$app_path" ]
+do
+ ls=$( ls -ld "$app_path" )
+ link=${ls#*' -> '}
+ case $link in #(
+ /*) app_path=$link ;; #(
+ *) app_path=$APP_HOME$link ;;
+ esac
done
-SAVED="`pwd`"
-cd "`dirname \"$PRG\"`/" >/dev/null
-APP_HOME="`pwd -P`"
-cd "$SAVED" >/dev/null
-APP_NAME="Gradle"
-APP_BASE_NAME=`basename "$0"`
-
-# Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
-DEFAULT_JVM_OPTS='"-Xmx64m" "-Xms64m"'
+# This is normally unused
+# shellcheck disable=SC2034
+APP_BASE_NAME=${0##*/}
+# Discard cd standard output in case $CDPATH is set (https://github.com/gradle/gradle/issues/25036)
+APP_HOME=$( cd -P "${APP_HOME:-./}" > /dev/null && printf '%s
+' "$PWD" ) || exit
# Use the maximum available, or set MAX_FD != -1 to use that value.
-MAX_FD="maximum"
+MAX_FD=maximum
warn () {
echo "$*"
-}
+} >&2
die () {
echo
echo "$*"
echo
exit 1
-}
+} >&2
# OS specific support (must be 'true' or 'false').
cygwin=false
msys=false
darwin=false
nonstop=false
-case "`uname`" in
- CYGWIN* )
- cygwin=true
- ;;
- Darwin* )
- darwin=true
- ;;
- MINGW* )
- msys=true
- ;;
- NONSTOP* )
- nonstop=true
- ;;
+case "$( uname )" in #(
+ CYGWIN* ) cygwin=true ;; #(
+ Darwin* ) darwin=true ;; #(
+ MSYS* | MINGW* ) msys=true ;; #(
+ NONSTOP* ) nonstop=true ;;
esac
CLASSPATH=$APP_HOME/gradle/wrapper/gradle-wrapper.jar
@@ -87,9 +122,9 @@ CLASSPATH=$APP_HOME/gradle/wrapper/gradle-wrapper.jar
if [ -n "$JAVA_HOME" ] ; then
if [ -x "$JAVA_HOME/jre/sh/java" ] ; then
# IBM's JDK on AIX uses strange locations for the executables
- JAVACMD="$JAVA_HOME/jre/sh/java"
+ JAVACMD=$JAVA_HOME/jre/sh/java
else
- JAVACMD="$JAVA_HOME/bin/java"
+ JAVACMD=$JAVA_HOME/bin/java
fi
if [ ! -x "$JAVACMD" ] ; then
die "ERROR: JAVA_HOME is set to an invalid directory: $JAVA_HOME
@@ -98,88 +133,120 @@ Please set the JAVA_HOME variable in your environment to match the
location of your Java installation."
fi
else
- JAVACMD="java"
- which java >/dev/null 2>&1 || die "ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
+ JAVACMD=java
+ if ! command -v java >/dev/null 2>&1
+ then
+ die "ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
Please set the JAVA_HOME variable in your environment to match the
location of your Java installation."
+ fi
fi
# Increase the maximum file descriptors if we can.
-if [ "$cygwin" = "false" -a "$darwin" = "false" -a "$nonstop" = "false" ] ; then
- MAX_FD_LIMIT=`ulimit -H -n`
- if [ $? -eq 0 ] ; then
- if [ "$MAX_FD" = "maximum" -o "$MAX_FD" = "max" ] ; then
- MAX_FD="$MAX_FD_LIMIT"
- fi
- ulimit -n $MAX_FD
- if [ $? -ne 0 ] ; then
- warn "Could not set maximum file descriptor limit: $MAX_FD"
- fi
- else
- warn "Could not query maximum file descriptor limit: $MAX_FD_LIMIT"
- fi
+if ! "$cygwin" && ! "$darwin" && ! "$nonstop" ; then
+ case $MAX_FD in #(
+ max*)
+ # In POSIX sh, ulimit -H is undefined. That's why the result is checked to see if it worked.
+ # shellcheck disable=SC2039,SC3045
+ MAX_FD=$( ulimit -H -n ) ||
+ warn "Could not query maximum file descriptor limit"
+ esac
+ case $MAX_FD in #(
+ '' | soft) :;; #(
+ *)
+ # In POSIX sh, ulimit -n is undefined. That's why the result is checked to see if it worked.
+ # shellcheck disable=SC2039,SC3045
+ ulimit -n "$MAX_FD" ||
+ warn "Could not set maximum file descriptor limit to $MAX_FD"
+ esac
fi
-# For Darwin, add options to specify how the application appears in the dock
-if $darwin; then
- GRADLE_OPTS="$GRADLE_OPTS \"-Xdock:name=$APP_NAME\" \"-Xdock:icon=$APP_HOME/media/gradle.icns\""
-fi
+# Collect all arguments for the java command, stacking in reverse order:
+# * args from the command line
+# * the main class name
+# * -classpath
+# * -D...appname settings
+# * --module-path (only if needed)
+# * DEFAULT_JVM_OPTS, JAVA_OPTS, and GRADLE_OPTS environment variables.
# For Cygwin or MSYS, switch paths to Windows format before running java
-if [ "$cygwin" = "true" -o "$msys" = "true" ] ; then
- APP_HOME=`cygpath --path --mixed "$APP_HOME"`
- CLASSPATH=`cygpath --path --mixed "$CLASSPATH"`
-
- JAVACMD=`cygpath --unix "$JAVACMD"`
-
- # We build the pattern for arguments to be converted via cygpath
- ROOTDIRSRAW=`find -L / -maxdepth 1 -mindepth 1 -type d 2>/dev/null`
- SEP=""
- for dir in $ROOTDIRSRAW ; do
- ROOTDIRS="$ROOTDIRS$SEP$dir"
- SEP="|"
- done
- OURCYGPATTERN="(^($ROOTDIRS))"
- # Add a user-defined pattern to the cygpath arguments
- if [ "$GRADLE_CYGPATTERN" != "" ] ; then
- OURCYGPATTERN="$OURCYGPATTERN|($GRADLE_CYGPATTERN)"
- fi
+if "$cygwin" || "$msys" ; then
+ APP_HOME=$( cygpath --path --mixed "$APP_HOME" )
+ CLASSPATH=$( cygpath --path --mixed "$CLASSPATH" )
+
+ JAVACMD=$( cygpath --unix "$JAVACMD" )
+
# Now convert the arguments - kludge to limit ourselves to /bin/sh
- i=0
- for arg in "$@" ; do
- CHECK=`echo "$arg"|egrep -c "$OURCYGPATTERN" -`
- CHECK2=`echo "$arg"|egrep -c "^-"` ### Determine if an option
-
- if [ $CHECK -ne 0 ] && [ $CHECK2 -eq 0 ] ; then ### Added a condition
- eval `echo args$i`=`cygpath --path --ignore --mixed "$arg"`
- else
- eval `echo args$i`="\"$arg\""
+ for arg do
+ if
+ case $arg in #(
+ -*) false ;; # don't mess with options #(
+ /?*) t=${arg#/} t=/${t%%/*} # looks like a POSIX filepath
+ [ -e "$t" ] ;; #(
+ *) false ;;
+ esac
+ then
+ arg=$( cygpath --path --ignore --mixed "$arg" )
fi
- i=`expr $i + 1`
+ # Roll the args list around exactly as many times as the number of
+ # args, so each arg winds up back in the position where it started, but
+ # possibly modified.
+ #
+ # NB: a `for` loop captures its iteration list before it begins, so
+ # changing the positional parameters here affects neither the number of
+ # iterations, nor the values presented in `arg`.
+ shift # remove old arg
+ set -- "$@" "$arg" # push replacement arg
done
- case $i in
- 0) set -- ;;
- 1) set -- "$args0" ;;
- 2) set -- "$args0" "$args1" ;;
- 3) set -- "$args0" "$args1" "$args2" ;;
- 4) set -- "$args0" "$args1" "$args2" "$args3" ;;
- 5) set -- "$args0" "$args1" "$args2" "$args3" "$args4" ;;
- 6) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" ;;
- 7) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" ;;
- 8) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" ;;
- 9) set -- "$args0" "$args1" "$args2" "$args3" "$args4" "$args5" "$args6" "$args7" "$args8" ;;
- esac
fi
-# Escape application args
-save () {
- for i do printf %s\\n "$i" | sed "s/'/'\\\\''/g;1s/^/'/;\$s/\$/' \\\\/" ; done
- echo " "
-}
-APP_ARGS=`save "$@"`
-# Collect all arguments for the java command, following the shell quoting and substitution rules
-eval set -- $DEFAULT_JVM_OPTS $JAVA_OPTS $GRADLE_OPTS "\"-Dorg.gradle.appname=$APP_BASE_NAME\"" -classpath "\"$CLASSPATH\"" org.gradle.wrapper.GradleWrapperMain "$APP_ARGS"
+# Add default JVM options here. You can also use JAVA_OPTS and GRADLE_OPTS to pass JVM options to this script.
+DEFAULT_JVM_OPTS='"-Xmx64m" "-Xms64m"'
+
+# Collect all arguments for the java command:
+# * DEFAULT_JVM_OPTS, JAVA_OPTS, JAVA_OPTS, and optsEnvironmentVar are not allowed to contain shell fragments,
+# and any embedded shellness will be escaped.
+# * For example: A user cannot expect ${Hostname} to be expanded, as it is an environment variable and will be
+# treated as '${Hostname}' itself on the command line.
+
+set -- \
+ "-Dorg.gradle.appname=$APP_BASE_NAME" \
+ -classpath "$CLASSPATH" \
+ org.gradle.wrapper.GradleWrapperMain \
+ "$@"
+
+# Stop when "xargs" is not available.
+if ! command -v xargs >/dev/null 2>&1
+then
+ die "xargs is not available"
+fi
+
+# Use "xargs" to parse quoted args.
+#
+# With -n1 it outputs one arg per line, with the quotes and backslashes removed.
+#
+# In Bash we could simply go:
+#
+# readarray ARGS < <( xargs -n1 <<<"$var" ) &&
+# set -- "${ARGS[@]}" "$@"
+#
+# but POSIX shell has neither arrays nor command substitution, so instead we
+# post-process each arg (as a line of input to sed) to backslash-escape any
+# character that might be a shell metacharacter, then use eval to reverse
+# that process (while maintaining the separation between arguments), and wrap
+# the whole thing up as a single "set" statement.
+#
+# This will of course break if any of these variables contains a newline or
+# an unmatched quote.
+#
+
+eval "set -- $(
+ printf '%s\n' "$DEFAULT_JVM_OPTS $JAVA_OPTS $GRADLE_OPTS" |
+ xargs -n1 |
+ sed ' s~[^-[:alnum:]+,./:=@_]~\\&~g; ' |
+ tr '\n' ' '
+ )" '"$@"'
exec "$JAVACMD" "$@"
diff --git a/light_client_app/android/gradlew.bat b/light_client_app/android/gradlew.bat
index ac1b06f9..9b42019c 100644
--- a/light_client_app/android/gradlew.bat
+++ b/light_client_app/android/gradlew.bat
@@ -13,8 +13,10 @@
@rem See the License for the specific language governing permissions and
@rem limitations under the License.
@rem
+@rem SPDX-License-Identifier: Apache-2.0
+@rem
-@if "%DEBUG%" == "" @echo off
+@if "%DEBUG%"=="" @echo off
@rem ##########################################################################
@rem
@rem Gradle startup script for Windows
@@ -25,7 +27,8 @@
if "%OS%"=="Windows_NT" setlocal
set DIRNAME=%~dp0
-if "%DIRNAME%" == "" set DIRNAME=.
+if "%DIRNAME%"=="" set DIRNAME=.
+@rem This is normally unused
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%
@@ -40,13 +43,13 @@ if defined JAVA_HOME goto findJavaFromJavaHome
set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
-if "%ERRORLEVEL%" == "0" goto execute
+if %ERRORLEVEL% equ 0 goto execute
-echo.
-echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH.
-echo.
-echo Please set the JAVA_HOME variable in your environment to match the
-echo location of your Java installation.
+echo. 1>&2
+echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH. 1>&2
+echo. 1>&2
+echo Please set the JAVA_HOME variable in your environment to match the 1>&2
+echo location of your Java installation. 1>&2
goto fail
@@ -56,11 +59,11 @@ set JAVA_EXE=%JAVA_HOME%/bin/java.exe
if exist "%JAVA_EXE%" goto execute
-echo.
-echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME%
-echo.
-echo Please set the JAVA_HOME variable in your environment to match the
-echo location of your Java installation.
+echo. 1>&2
+echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME% 1>&2
+echo. 1>&2
+echo Please set the JAVA_HOME variable in your environment to match the 1>&2
+echo location of your Java installation. 1>&2
goto fail
@@ -75,13 +78,15 @@ set CLASSPATH=%APP_HOME%\gradle\wrapper\gradle-wrapper.jar
:end
@rem End local scope for the variables with windows NT shell
-if "%ERRORLEVEL%"=="0" goto mainEnd
+if %ERRORLEVEL% equ 0 goto mainEnd
:fail
rem Set variable GRADLE_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
-if not "" == "%GRADLE_EXIT_CONSOLE%" exit 1
-exit /b 1
+set EXIT_CODE=%ERRORLEVEL%
+if %EXIT_CODE% equ 0 set EXIT_CODE=1
+if not ""=="%GRADLE_EXIT_CONSOLE%" exit %EXIT_CODE%
+exit /b %EXIT_CODE%
:mainEnd
if "%OS%"=="Windows_NT" endlocal
diff --git a/wallet_app/android/.idea/compiler.xml b/wallet_app/android/.idea/compiler.xml
new file mode 100644
index 00000000..b86273d9
--- /dev/null
+++ b/wallet_app/android/.idea/compiler.xml
@@ -0,0 +1,6 @@
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/.idea/deploymentTargetSelector.xml b/wallet_app/android/.idea/deploymentTargetSelector.xml
new file mode 100644
index 00000000..33fbba45
--- /dev/null
+++ b/wallet_app/android/.idea/deploymentTargetSelector.xml
@@ -0,0 +1,18 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/.idea/gradle.xml b/wallet_app/android/.idea/gradle.xml
new file mode 100644
index 00000000..7b3006b6
--- /dev/null
+++ b/wallet_app/android/.idea/gradle.xml
@@ -0,0 +1,20 @@
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/.idea/inspectionProfiles/Project_Default.xml b/wallet_app/android/.idea/inspectionProfiles/Project_Default.xml
new file mode 100644
index 00000000..e0da3ee5
--- /dev/null
+++ b/wallet_app/android/.idea/inspectionProfiles/Project_Default.xml
@@ -0,0 +1,73 @@
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/.idea/kotlinc.xml b/wallet_app/android/.idea/kotlinc.xml
new file mode 100644
index 00000000..6d0ee1c2
--- /dev/null
+++ b/wallet_app/android/.idea/kotlinc.xml
@@ -0,0 +1,6 @@
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/.idea/misc.xml b/wallet_app/android/.idea/misc.xml
new file mode 100644
index 00000000..74dd639e
--- /dev/null
+++ b/wallet_app/android/.idea/misc.xml
@@ -0,0 +1,10 @@
+
+
+
+
+
+
+
+
+
+
\ No newline at end of file
diff --git a/wallet_app/android/local.properties b/wallet_app/android/local.properties
new file mode 100644
index 00000000..3c4dc84c
--- /dev/null
+++ b/wallet_app/android/local.properties
@@ -0,0 +1,8 @@
+## This file must *NOT* be checked into Version Control Systems,
+# as it contains information specific to your local configuration.
+#
+# Location of the SDK. This is only used by Gradle.
+# For customization when using a Version Control System, please read the
+# header note.
+#Tue Oct 08 15:18:36 CDT 2024
+sdk.dir=/Users/max/Library/Android/sdk
diff --git a/wallet_app/app/.gitignore b/wallet_app/app/.gitignore
index 42afabfd..591843f0 100644
--- a/wallet_app/app/.gitignore
+++ b/wallet_app/app/.gitignore
@@ -1 +1,2 @@
-/build
\ No newline at end of file
+android/app/build
+build
\ No newline at end of file
diff --git a/wallet_app/app/build.gradle.kts b/wallet_app/app/build.gradle.kts
index 8072c8cc..41e6c2b0 100644
--- a/wallet_app/app/build.gradle.kts
+++ b/wallet_app/app/build.gradle.kts
@@ -1,4 +1,3 @@
-import kotlinx.serialization.serializer
import java.util.Properties
plugins {
@@ -6,7 +5,9 @@ plugins {
alias(libs.plugins.jetbrains.kotlin.android)
id("kotlin-kapt")
id("org.jmailen.kotlinter")
- kotlin("plugin.serialization") version "2.0.21"
+ kotlin("plugin.serialization") version "2.0.0-RC1"
+ alias(libs.plugins.compose.compiler)
+
}
android {
@@ -60,7 +61,7 @@ android {
jvmTarget = "17"
}
composeOptions {
- kotlinCompilerExtensionVersion = "1.5.1"
+ kotlinCompilerExtensionVersion = "1.5.7"
}
packaging {
resources {
@@ -70,6 +71,9 @@ android {
}
dependencies {
+ implementation("com.swmansion.starknet:starknet:0.13.0@aar"){
+ isTransitive = true
+ }
// Navigation stuff
implementation(libs.androidx.navigation.compose.v283)
implementation(libs.androidx.navigation.compose.v283)
@@ -78,9 +82,8 @@ dependencies {
implementation(libs.androidx.navigation.dynamic.features.fragment)
androidTestImplementation(libs.androidx.navigation.testing)
- implementation("com.swmansion.starknet:starknet:0.12.1@aar"){
- isTransitive = true
- }
+
+ implementation(libs.androidx.security.crypto.v110alpha06)
// for data binding
implementation(libs.common)
diff --git a/wallet_app/app/src/main/java/com/example/walletapp/ui/MainActivity.kt b/wallet_app/app/src/main/java/com/example/walletapp/ui/MainActivity.kt
index 4fde3df0..d4871733 100644
--- a/wallet_app/app/src/main/java/com/example/walletapp/ui/MainActivity.kt
+++ b/wallet_app/app/src/main/java/com/example/walletapp/ui/MainActivity.kt
@@ -1,12 +1,26 @@
package com.example.walletapp.ui
+import android.content.Context
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.core.view.WindowCompat
+import com.example.walletapp.BuildConfig
+import com.example.walletapp.utils.StarknetClient
class MainActivity : ComponentActivity() {
+ init {
+ instance = this
+ }
+
+ companion object {
+ private var instance: MainActivity? = null
+
+ fun applicationContext() : Context {
+ return instance!!.applicationContext
+ }
+ }
override fun onCreate(savedInstanceState: Bundle?) {
super.onCreate(savedInstanceState)
enableEdgeToEdge()
diff --git a/wallet_app/app/src/main/java/com/example/walletapp/ui/WalletApp.kt b/wallet_app/app/src/main/java/com/example/walletapp/ui/WalletApp.kt
index 38c40a71..02fb127f 100644
--- a/wallet_app/app/src/main/java/com/example/walletapp/ui/WalletApp.kt
+++ b/wallet_app/app/src/main/java/com/example/walletapp/ui/WalletApp.kt
@@ -11,7 +11,7 @@ import com.example.walletapp.ui.activity.FinalizeAccountCreationScreen
import com.example.walletapp.ui.onboarding.CreateAccountScreen
import com.example.walletapp.ui.onboarding.CreatePinScreen
import com.example.walletapp.ui.onboarding.ImportAccountScreen
-import com.example.walletapp.ui.onboarding.border.OnboardingScreen
+import com.example.walletapp.ui.onboarding.OnboardingScreen
import com.example.walletapp.ui.theme.WalletappTheme
import com.example.walletapp.ui.transfer.ReceiveScreen
import com.example.walletapp.ui.transfer.SendScreen
diff --git a/wallet_app/app/src/main/java/com/example/walletapp/ui/onboarding/OnboardingScreen.kt b/wallet_app/app/src/main/java/com/example/walletapp/ui/onboarding/OnboardingScreen.kt
index 76590e65..1372106f 100644
--- a/wallet_app/app/src/main/java/com/example/walletapp/ui/onboarding/OnboardingScreen.kt
+++ b/wallet_app/app/src/main/java/com/example/walletapp/ui/onboarding/OnboardingScreen.kt
@@ -1,8 +1,7 @@
package com.example.walletapp.ui.onboarding
-.border
-import android.app.Activity
+
import androidx.compose.foundation.background
import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
diff --git a/wallet_app/app/src/main/java/com/example/walletapp/utils/Keystore.kt b/wallet_app/app/src/main/java/com/example/walletapp/utils/Keystore.kt
new file mode 100644
index 00000000..45bf079e
--- /dev/null
+++ b/wallet_app/app/src/main/java/com/example/walletapp/utils/Keystore.kt
@@ -0,0 +1,63 @@
+package com.example.walletapp.utils
+
+import android.util.Log
+import androidx.security.crypto.EncryptedSharedPreferences
+import androidx.security.crypto.MasterKey
+import com.example.walletapp.ui.MainActivity
+import java.io.IOException
+import java.security.GeneralSecurityException
+
+class Keystore() {
+
+ private val tag = "Keystore"
+ val context = MainActivity.applicationContext()
+ fun storeData(message: String) {
+ try {
+ val masterKey = MasterKey.Builder(context)
+ .setKeyScheme(MasterKey.KeyScheme.AES256_GCM)
+ .build()
+
+ val sharedPreferences = EncryptedSharedPreferences.create(
+ context,
+ "my_encrypted_prefs",
+ masterKey,
+ EncryptedSharedPreferences.PrefKeyEncryptionScheme.AES256_SIV,
+ EncryptedSharedPreferences.PrefValueEncryptionScheme.AES256_GCM
+ )
+
+ val editor = sharedPreferences.edit()
+ editor.putString("key", message)
+ editor.apply()
+
+ } catch (e: GeneralSecurityException) {
+ Log.e(tag, "Security exception while storing data: ${e.message}", e)
+ } catch (e: IOException) {
+ Log.e(tag, "I/O exception while storing data: ${e.message}", e)
+ }
+ }
+
+ fun retrieveData(): String {
+ try {
+ val masterKey = MasterKey.Builder(context)
+ .setKeyScheme(MasterKey.KeyScheme.AES256_GCM)
+ .build()
+
+ val sharedPreferences = EncryptedSharedPreferences.create(
+ context,
+ "my_encrypted_prefs",
+ masterKey,
+ EncryptedSharedPreferences.PrefKeyEncryptionScheme.AES256_SIV,
+ EncryptedSharedPreferences.PrefValueEncryptionScheme.AES256_GCM
+ )
+
+ return sharedPreferences.getString("key", "") ?: ""
+
+ } catch (e: GeneralSecurityException) {
+ Log.e(tag, "Security exception while retrieving data: ${e.message}", e)
+ return ""
+ } catch (e: IOException) {
+ Log.e(tag, "I/O exception while retrieving data: ${e.message}", e)
+ return ""
+ }
+ }
+}
\ No newline at end of file
diff --git a/wallet_app/gradle/libs.versions.toml b/wallet_app/gradle/libs.versions.toml
index 3bbea0dd..435a71df 100644
--- a/wallet_app/gradle/libs.versions.toml
+++ b/wallet_app/gradle/libs.versions.toml
@@ -1,5 +1,5 @@
[versions]
-activityCompose = "1.9.1"
+activityCompose = "1.9.3"
agp = "8.5.2"
common = "1.1.1"
converterGson = "2.9.0"
@@ -7,7 +7,7 @@ core = "4.8.7"
hiltAndroid = "2.51"
hiltNavigationCompose = "1.2.0"
hiltNavigationComposeVersion = "1.2.0"
-kotlin = "1.9.0"
+kotlin = "2.0.0"
coreKtx = "1.13.1"
junit = "4.13.2"
junitVersion = "1.2.1"
@@ -15,18 +15,20 @@ espressoCore = "3.6.1"
appcompat = "1.7.0"
kotlinxCoroutinesAndroid = "1.7.3"
kotlinxCoroutinesCore = "1.7.3"
-lifecycleViewmodelCompose = "2.8.4"
+lifecycleViewmodelCompose = "2.8.6"
loggingInterceptor = "4.11.0"
material = "1.12.0"
-activity = "1.9.1"
+activity = "1.9.3"
constraintlayout = "2.1.4"
-navigationCompose = "2.7.7"
+navigationCompose = "2.8.3"
navigationComposeVersion = "2.8.3"
navigationDynamicFeaturesFragment = "2.8.3"
navigationFragment = "2.8.3"
navigationTesting = "2.8.3"
navigationUi = "2.8.3"
retrofit = "2.9.0"
+securityCrypto = "1.0.0"
+securityCryptoVersion = "1.1.0-alpha06"
[libraries]
androidx-activity-compose = { module = "androidx.activity:activity-compose", version.ref = "activityCompose" }
@@ -44,6 +46,8 @@ androidx-navigation-fragment = { module = "androidx.navigation:navigation-fragme
androidx-navigation-testing = { module = "androidx.navigation:navigation-testing", version.ref = "navigationTesting" }
androidx-navigation-ui = { module = "androidx.navigation:navigation-ui", version.ref = "navigationUi" }
androidx-runtime-livedata = { module = "androidx.compose.runtime:runtime-livedata" }
+androidx-security-crypto = { module = "androidx.security:security-crypto", version.ref = "securityCrypto" }
+androidx-security-crypto-v110alpha06 = { module = "androidx.security:security-crypto", version.ref = "securityCryptoVersion" }
androidx-ui-tooling = { module = "androidx.compose.ui:ui-tooling" }
androidx-ui-tooling-preview = { module = "androidx.compose.ui:ui-tooling-preview" }
common = { module = "android.arch.lifecycle:common", version.ref = "common" }
@@ -65,4 +69,6 @@ retrofit = { module = "com.squareup.retrofit2:retrofit", version.ref = "retrofit
[plugins]
android-application = { id = "com.android.application", version.ref = "agp" }
jetbrains-kotlin-android = { id = "org.jetbrains.kotlin.android", version.ref = "kotlin" }
+compose-compiler = { id = "org.jetbrains.kotlin.plugin.compose", version.ref = "kotlin" }
+
diff --git a/wallet_app/app/src/main/java/com/example/walletapp/utils/StarknetClient.kt b/wallet_app/app/src/main/java/com/example/walletapp/utils/StarknetClient.kt
index c32ac227..ff3401c6 100644
--- a/wallet_app/app/src/main/java/com/example/walletapp/utils/StarknetClient.kt
+++ b/wallet_app/app/src/main/java/com/example/walletapp/utils/StarknetClient.kt
@@ -11,21 +11,37 @@ import com.swmansion.starknet.account.Account
import kotlinx.coroutines.future.await
import java.math.BigDecimal
+import android.util.Log
+import com.swmansion.starknet.data.types.CairoVersion
+import androidx.security.crypto.EncryptedSharedPreferences;
+import androidx.security.crypto.MasterKey;
+import android.content.Context
+import com.swmansion.starknet.crypto.StarknetCurve
+import com.swmansion.starknet.extensions.toFelt
+import com.swmansion.starknet.extensions.toNumAsHex
+import java.io.IOException
+import java.math.BigInteger
+import java.security.GeneralSecurityException
const val ETH_ERC20_ADDRESS = "0x049d36570d4e46f48e99674bd3fcc84644ddd6b96f7c741b1562b82f9e004dc7"
class StarknetClient(private val rpcUrl: String) {
private val provider = JsonRpcProvider(rpcUrl)
- private val privateKey= BuildConfig.PRIVATE_KEY
- private val accountAddress= BuildConfig.ACCOUNT_ADDRESS
+ private val privateKey = BuildConfig.PRIVATE_KEY
+ private val accountAddress = BuildConfig.ACCOUNT_ADDRESS
+ private val tag = "StarknetClient"
+ private val keystore = Keystore()
suspend fun deployAccount() {
+ // Predefined values for account creation
+ val randomPrivateKey = StandardAccount.generatePrivateKey()
+ keystore.storeData(randomPrivateKey.value.toString()) // save the key generated
+ val data = keystore.retrieveData() // retrieve it to generate public key
+ val privateKey = BigInteger(data).toFelt
- // Predefined values for account creation
- val privateKey = Felt.fromHex(privateKey)
- val accountAddress = Felt.fromHex(accountAddress)
+ val accountAddress = StarknetCurve.getPublicKey(privateKey)
val signer = StarkCurveSigner(privateKey)
val chainId = provider.getChainId().sendAsync().await()
@@ -34,7 +50,7 @@ class StarknetClient(private val rpcUrl: String) {
signer = signer,
provider = provider,
chainId = chainId,
- cairoVersion = Felt.ONE,
+ cairoVersion = CairoVersion.ONE,
)
// TODO(#99): add account deployment logic